PickedData class

Data returned when a location is picked.

Constructors

PickedData(LatLong latLong, String addressName, Map<String, dynamic> address)
const

Properties

address Map<String, dynamic>
A map containing detailed address components (city, country, etc.).
final
addressName String
The full display name of the address.
final
hashCode int
The hash code for this object.
no setterinherited
latLong LatLong
The GPS coordinates of the picked location.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited