ZoneData class

Represents a zone to be drawn on the map as a circle.

Constructors

ZoneData({required LatLong center, required double radius, Color color = const Color(0x332196F3), Color borderColor = const Color(0xFF2196F3), double borderStrokeWidth = 0.0, bool useFillColor = true, Widget? detailWidget, String detail = '', String title = '', void onTap()?})

Properties

borderColor Color
final
borderStrokeWidth double
final
center LatLong
final
color Color
final
detail String
final
detailWidget Widget?
final
hashCode int
The hash code for this object.
no setterinherited
onTap → void Function()?
final
radius double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final
useFillColor bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited