RouteData class
Represents a polyline route to be drawn on the map.
Constructors
Properties
- color → Color
-
The colour of the route line. Defaults to blue.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDotted → bool
-
Whether the route line should be dotted. Defaults to false.
final
- label → String?
-
Optional label shown alongside the route.
final
-
points
→ List<
LatLong> -
The list of waypoints that form the route.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- strokeWidth → double
-
The stroke width of the route line. Defaults to 4.0.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited